@@ -14,6 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from polyaxon import pkg
 
 VERSION_V1 = "v1"
 API_V1 = "api/{}".format(VERSION_V1)
@@ -22,5 +23,23 @@ SERVICES_V1 = "services/{}".format(VERSION_V1)
 REWRITE_SERVICES_V1 = "rewrite-services/{}".format(VERSION_V1)
 WS_V1 = "ws/{}".format(VERSION_V1)
 AUTH_V1 = "auth/{}".format(VERSION_V1)
-POLYAXON_CLOUD = "cloud.polyaxon.com"
+STATIC_V1 = "static/{}".format(VERSION_V1)
+UI_V1 = "ui"
+ADMIN_V1 = "_admin"
+API_V1_LOCATION = "/" + API_V1 + "/"
+UI_V1_LOCATION = "/" + UI_V1 + "/"
+STATIC_V1_LOCATION = "/" + STATIC_V1 + "/"
+ADMIN_V1_LOCATION = "/" + ADMIN_V1 + "/"
+AUTH_V1_LOCATION = "/" + AUTH_V1 + "/"
+HEALTHZ_LOCATION = "/healthz/"
 POLYAXON_CLOUD_HOST = "https://cloud.polyaxon.com"
+LOCALHOST = "http://localhost:8000"
+POLYAXON_VERSIONS_HOST = "https://versions.polyaxon.com/?v={}".format(pkg.VERSION)
+
+
+def get_default_host(host: str = None, service: str = None):
+    if host:
+        return host
+    if service is None:
+        return POLYAXON_CLOUD_HOST
+    return LOCALHOST
