@@ -23,24 +23,20 @@ from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
 from polyaxon.cli.errors import handle_cli_error
-from polyaxon.cli.version import (
-    get_current_version,
-    get_log_handler,
-    get_server_versions,
-)
+from polyaxon.cli.session import session_expired, set_versions_config
 from polyaxon.client import PolyaxonClient
-from polyaxon.logger import clean_outputs, logger
+from polyaxon.logger import logger
 from polyaxon.managers.auth import AuthConfigManager
 from polyaxon.managers.cli import CliConfigManager
 from polyaxon.schemas.api.authentication import AccessTokenConfig, V1Credentials
 from polyaxon.utils.formatting import Printer, dict_tabulate, dict_to_tabulate
+from polyaxon.utils.http_utils import polyaxon_ui
 
 
 @click.command()
 @click.option("--token", "-t", help="Polyaxon token.")
 @click.option("--username", "-u", help="Polyaxon username or email.")
 @click.option("--password", "-p", help="Polyaxon password.")
-@clean_outputs
 def login(token, username, password):
     """Login to Polyaxon."""
     polyaxon_client = PolyaxonClient()
@@ -72,7 +68,9 @@ def login(token, username, password):
             return
     else:
         if not token:
-            token_url = "{}/app/token".format(polyaxon_client.config.host)
+            token_url = "{}/profile/token".format(
+                polyaxon_ui(polyaxon_client.config.host)
+            )
             click.confirm(
                 "Authentication token page will now open in your browser. Continue?",
                 abort=True,
@@ -112,20 +110,10 @@ def login(token, username, password):
     polyaxon_client.config.token = access_auth.token
     Printer.print_success("Login successful")
 
-    # Reset current cli
-    server_versions = get_server_versions(polyaxon_client=polyaxon_client)
-    current_version = get_current_version()
-    log_handler = get_log_handler(polyaxon_client=polyaxon_client)
-    CliConfigManager.reset(
-        check_count=0,
-        current_version=current_version,
-        server_versions=server_versions.to_dict(),
-        log_handler=log_handler,
-    )
+    set_versions_config(polyaxon_client=polyaxon_client, set_handler=True)
 
 
 @click.command()
-@clean_outputs
 def logout():
     """Logout of Polyaxon."""
     AuthConfigManager.purge()
@@ -134,17 +122,18 @@ def logout():
 
 
 @click.command()
-@clean_outputs
 def whoami():
     """Show current logged Polyaxon user."""
     try:
         polyaxon_client = PolyaxonClient()
         user = polyaxon_client.users_v1.get_user()
+    except ApiException as e:
+        if e.status == 403:
+            session_expired()
+        handle_cli_error(e, message="Could not get the user info.", sys_exit=True)
     except (ApiException, HTTPError) as e:
-        handle_cli_error(e, message="Could not load user info.")
-        sys.exit(1)
+        handle_cli_error(e, message="Could not load user info.", sys_exit=True)
 
     response = dict_to_tabulate(user.to_dict(), exclude_attrs=["role"])
-
     Printer.print_header("User info:")
     dict_tabulate(response)
