@@ -19,7 +19,7 @@ import sys
 import click
 
 from polyaxon import settings
-from polyaxon.logger import clean_outputs
+from polyaxon.utils.http_utils import polyaxon_ui
 
 
 @click.command()
@@ -34,10 +34,9 @@ from polyaxon.logger import clean_outputs
 @click.option(
     "--url", is_flag=True, default=False, help="Print the url of the dashboard."
 )
-@clean_outputs
 def dashboard(yes, url):
     """Open dashboard in browser."""
-    dashboard_url = settings.CLIENT_CONFIG.host
+    dashboard_url = "{}/".format(polyaxon_ui(settings.CLIENT_CONFIG.host))
     if url:
         click.echo(dashboard_url)
         sys.exit(0)
