@@ -22,15 +22,14 @@ from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
 from polyaxon import settings
-from polyaxon.api import SERVICES_V1
+from polyaxon.api import REWRITE_SERVICES_V1, SERVICES_V1
 from polyaxon.cli.errors import handle_cli_error
-from polyaxon.cli.upload import upload
 from polyaxon.client import RunClient
 from polyaxon.client.run import get_run_logs
 from polyaxon.config_reader.spec import ConfigSpec
 from polyaxon.env_vars.getters import get_project_or_local, get_project_run_or_local
 from polyaxon.exceptions import PolyaxonClientException
-from polyaxon.logger import clean_outputs
+from polyaxon.lifecycle import LifeCycle, V1Statuses
 from polyaxon.managers.run import RunManager
 from polyaxon.polyflow import V1RunKind
 from polyaxon.utils import cache
@@ -42,6 +41,7 @@ from polyaxon.utils.formatting import (
     get_runs_with_keys,
     list_dicts_to_tabulate,
 )
+from polyaxon.utils.http_utils import clean_host, polyaxon_ui
 from polyaxon.utils.validation import validate_tags
 
 
@@ -83,7 +83,6 @@ def get_run_details(run):  # pylint:disable=redefined-outer-name
 )
 @click.option("--uid", "-uid", type=str, help="The run uuid.")
 @click.pass_context
-@clean_outputs
 def ops(ctx, project, uid):
     """Commands for ops/runs."""
     ctx.obj = ctx.obj or {}
@@ -106,8 +105,6 @@ def ops(ctx, project, uid):
 @click.option("--limit", type=int, help="To limit the list of runs.")
 @click.option("--offset", type=int, help="To offset the list of runs.")
 @click.pass_context
-@clean_outputs
-@clean_outputs
 def ls(ctx, io, query, sort, limit, offset):
     """List runs for this project.
 
@@ -220,7 +217,6 @@ def ls(ctx, io, query, sort, limit, offset):
 
 @ops.command()
 @click.pass_context
-@clean_outputs
 def get(ctx):
     """Get run.
 
@@ -253,7 +249,9 @@ def get(ctx):
         config = polyaxon_client.client.sanitize_for_serialization(
             polyaxon_client.run_data
         )
-        cache.cache(config_manager=RunManager, config=config)
+        cache.cache(
+            config_manager=RunManager, config=config, owner=owner, project=project_name
+        )
     except (ApiException, HTTPError) as e:
         handle_cli_error(e, message="Could not load run `{}` info.".format(run_uuid))
         sys.exit(1)
@@ -263,7 +261,6 @@ def get(ctx):
 
 @ops.command()
 @click.pass_context
-@clean_outputs
 def delete(ctx):
     """Delete a run.
 
@@ -308,7 +305,6 @@ def delete(ctx):
     "--tags", type=str, help="Tags of the run, comma separated values (optional)."
 )
 @click.pass_context
-@clean_outputs
 def update(ctx, name, description, tags):
     """Update run.
 
@@ -366,7 +362,6 @@ def update(ctx, name, description, tags):
     'Assume "yes" as answer to all prompts and run non-interactively.',
 )
 @click.pass_context
-@clean_outputs
 def stop(ctx, yes):
     """Stop run.
 
@@ -417,12 +412,8 @@ def stop(ctx, yes):
     type=click.Path(exists=True),
     help="The polyaxonfiles to update with.",
 )
-@click.option(
-    "-u", is_flag=True, default=False, help="To upload the repo before restarting."
-)
 @click.pass_context
-@clean_outputs
-def restart(ctx, copy, polyaxonfile, u):
+def restart(ctx, copy, polyaxonfile):
     """Restart run.
 
     Uses /docs/core/cli/#caching
@@ -436,10 +427,6 @@ def restart(ctx, copy, polyaxonfile, u):
     if polyaxonfile:
         content = "{}".format(ConfigSpec.read_from(polyaxonfile))
 
-    # Check if we need to upload
-    if u:
-        ctx.invoke(upload, sync=False)
-
     owner, project_name, run_uuid = get_project_run_or_local(
         ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
     )
@@ -467,12 +454,8 @@ def restart(ctx, copy, polyaxonfile, u):
     type=click.Path(exists=True),
     help="The polyaxonfiles to update with.",
 )
-@click.option(
-    "-u", is_flag=True, default=False, help="To upload the repo before resuming."
-)
 @click.pass_context
-@clean_outputs
-def resume(ctx, polyaxonfile, u):
+def resume(ctx, polyaxonfile):
     """Resume run.
 
     Uses /docs/core/cli/#caching
@@ -486,10 +469,6 @@ def resume(ctx, polyaxonfile, u):
     if polyaxonfile:
         content = "{}".format(ConfigSpec.read_from(polyaxonfile))
 
-    # Check if we need to upload
-    if u:
-        ctx.invoke(upload, sync=False)
-
     owner, project_name, run_uuid = get_project_run_or_local(
         ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
     )
@@ -506,7 +485,6 @@ def resume(ctx, polyaxonfile, u):
 
 @ops.command()
 @click.pass_context
-@clean_outputs
 def invalidate(ctx):
     """Invalidate the run's cache state.
 
@@ -535,7 +513,6 @@ def invalidate(ctx):
 @ops.command()
 @click.option("--watch", "-w", is_flag=True, help="Watch statuses.")
 @click.pass_context
-@clean_outputs
 def statuses(ctx, watch):
     """Get run or run job statuses.
 
@@ -597,7 +574,6 @@ def statuses(ctx, watch):
 # @ops.command()
 # @click.option("--gpu", "-g", is_flag=True, help="List run GPU resources.")
 # @click.pass_context
-# @clean_outputs
 # def resources(ctx, gpu):
 #     """Get run or run job resources.
 #
@@ -642,21 +618,20 @@ def statuses(ctx, watch):
     help="Stream logs after showing past logs.",
 )
 @click.option(
-    "--hide_time",
     "--hide-time",
+    "-h",
     is_flag=True,
     default=False,
     help="Whether or not to hide timestamps from the log stream.",
 )
 @click.option(
-    "--all_info",
     "--all-info",
+    "-a",
     is_flag=True,
     default=False,
     help="Whether to stream logs from all containers.",
 )
 @click.pass_context
-@clean_outputs
 def logs(ctx, follow, hide_time, all_info):
     """Get run or run job logs.
 
@@ -683,7 +658,6 @@ def logs(ctx, follow, hide_time, all_info):
 
 @ops.command()
 @click.pass_context
-@clean_outputs
 def artifacts(ctx):
     """Download outputs/artifacts for run.
 
@@ -718,17 +692,58 @@ def artifacts(ctx):
     'Assume "yes" as answer to all prompts and run non-interactively.',
 )
 @click.option(
-    "--external",
+    "--url",
     is_flag=True,
     default=False,
-    help="Open the dashboard on a service URL and not on the dashboard URL.",
+    help="Print the url of the dashboard for this run.",
 )
+@click.pass_context
+def dashboard(ctx, yes, url):
+    """Open this operation's dashboard details in browser."""
+    owner, project_name, run_uuid = get_project_run_or_local(
+        ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
+    )
+    dashboard_url = polyaxon_ui(settings.CLIENT_CONFIG.host)
+    run_url = "{}/{}/{}/runs/{}/".format(dashboard_url, owner, project_name, run_uuid)
+    if url:
+        Printer.print_header("The dashboard is available at: {}".format(run_url))
+        sys.exit(0)
+    if not yes:
+        click.confirm(
+            "Dashboard page will now open in your browser. Continue?",
+            abort=True,
+            default=True,
+        )
+    click.launch(run_url)
+
+
+@ops.command()
 @click.option(
-    "--url", is_flag=True, default=False, help="Print the url of the dashboard."
+    "--yes",
+    "-y",
+    is_flag=True,
+    default=False,
+    help="Automatic yes to prompts. "
+    'Assume "yes" as answer to all prompts and run non-interactively.',
+)
+@click.option(
+    "--external", is_flag=True, default=False, help="Open the external service URL.",
+)
+@click.option(
+    "--url",
+    is_flag=True,
+    default=False,
+    help="Print the url of the dashboard or external service.",
 )
 @click.pass_context
-@clean_outputs
 def service(ctx, yes, external, url):
+    """Open the operation service in browser.
+
+    N.B. The operation must have a run kind service, otherwise it will raise an error.
+
+    You can open the service embedded in Polyaxon UI or using the real service URL,
+    please use the `--external` flag.
+    """
     owner, project_name, run_uuid = get_project_run_or_local(
         ctx.obj.get("project"), ctx.obj.get("run_uuid"), is_cli=True,
     )
@@ -736,21 +751,36 @@ def service(ctx, yes, external, url):
     client.refresh_data()
     if client.run_data.kind != V1RunKind.SERVICE:
         Printer.print_warning(
-            "Command expected a operations of "
+            "Command expected an operation of "
             "kind `service` received kind: {}!".format(client.run_data.kind)
         )
         sys.exit(1)
-    dashboard_url = settings.CLIENT_CONFIG.host
+    dashboard_url = polyaxon_ui(settings.CLIENT_CONFIG.host)
+    host = clean_host(settings.CLIENT_CONFIG.host)
 
-    namespace = "polyaxon"
-    if client.run_data.settings:
-        namespace = client.run_data.settings.namespace
+    Printer.print_header("Waiting for running condition ...")
+    client.wait_for_condition(
+        statuses={V1Statuses.RUNNING} | LifeCycle.DONE_VALUES, print_status=True
+    )
+
+    client.refresh_data()
+    if LifeCycle.is_done(client.run_data.status):
+        Printer.print_header("The operations reached a done statuses.")
+        latest_status = Printer.add_status_color(
+            {"status": client.run_data.status}, status_key="status"
+        )
+        click.echo("{}\n".format(latest_status["status"]))
+
+    namespace = client.run_data.settings.namespace
 
     run_url = "{}/{}/{}/runs/{}/service".format(
         dashboard_url, owner, project_name, run_uuid
     )
+    service_endpoint = SERVICES_V1
+    if client.run_data.meta_info.get("rewrite_path", False):
+        service_endpoint = REWRITE_SERVICES_V1
     external_run_url = "{}/{}/{}/{}/{}/runs/{}/".format(
-        dashboard_url, SERVICES_V1, namespace, owner, project_name, run_uuid
+        host, service_endpoint, namespace, owner, project_name, run_uuid
     )
     if url:
         Printer.print_header("The service will be available at: {}".format(run_url))
@@ -766,4 +796,5 @@ def service(ctx, yes, external, url):
         )
     if external:
         click.launch(external_run_url)
+        sys.exit(0)
     click.launch(run_url)
