@@ -22,12 +22,12 @@ from polyaxon_sdk import V1Project
 from polyaxon_sdk.rest import ApiException
 from urllib3.exceptions import HTTPError
 
+from polyaxon import settings
 from polyaxon.cli.errors import handle_cli_error
 from polyaxon.cli.init import init as init_project
 from polyaxon.client import ProjectClient
+from polyaxon.constants import DEFAULT
 from polyaxon.env_vars.getters import get_project_or_local
-from polyaxon.logger import clean_outputs
-from polyaxon.managers.auth import AuthConfigManager
 from polyaxon.managers.project import ProjectManager
 from polyaxon.utils import cache
 from polyaxon.utils.formatting import (
@@ -37,6 +37,7 @@ from polyaxon.utils.formatting import (
     get_meta_response,
     list_dicts_to_tabulate,
 )
+from polyaxon.utils.http_utils import polyaxon_ui
 from polyaxon.utils.validation import validate_tags
 
 
@@ -56,7 +57,6 @@ def get_project_details(project):
 @click.group()
 @click.option("--project", "-p", type=str)
 @click.pass_context
-@clean_outputs
 def project(ctx, project):  # pylint:disable=redefined-outer-name
     """Commands for projects."""
     if ctx.invoked_subcommand not in ["create", "ls"]:
@@ -84,7 +84,6 @@ def project(ctx, project):  # pylint:disable=redefined-outer-name
 )
 @click.option("--init", is_flag=True, help="Initialize the project after creation.")
 @click.pass_context
-@clean_outputs
 def create(ctx, name, owner, description, tags, private, init):
     """Create a new project.
 
@@ -95,7 +94,7 @@ def create(ctx, name, owner, description, tags, private, init):
     \b
     $ polyaxon project create --name=cats-vs-dogs --description="Image Classification with DL"
     """
-    owner = owner or AuthConfigManager.get_value("username")
+    owner = owner or settings.AUTH_CONFIG.username or DEFAULT
     tags = validate_tags(tags)
 
     if not owner:
@@ -109,7 +108,10 @@ def create(ctx, name, owner, description, tags, private, init):
         project_config = V1Project(
             name=name, description=description, tags=tags, is_public=not private
         )
-        _project = ProjectClient(owner=owner).create(project_config)
+        polyaxon_client = ProjectClient(owner=owner)
+        _project = polyaxon_client.create(project_config)
+        config = polyaxon_client.client.sanitize_for_serialization(_project)
+        cache.cache(config_manager=ProjectManager, config=config)
     except (ApiException, HTTPError) as e:
         handle_cli_error(e, message="Could not create project `{}`.".format(name))
         sys.exit(1)
@@ -132,13 +134,12 @@ def create(ctx, name, owner, description, tags, private, init):
 )
 @click.option("--limit", type=int, help="To limit the list of projects.")
 @click.option("--offset", type=int, help="To offset the list of projects.")
-@clean_outputs
 def ls(owner, limit, offset):
     """List projects.
 
     Uses /docs/core/cli/#caching
     """
-    owner = owner or AuthConfigManager.get_value("username")
+    owner = owner or settings.AUTH_CONFIG.username or DEFAULT
     if not owner:
         Printer.print_error(
             "Please login first or provide a valid owner --owner. "
@@ -183,7 +184,6 @@ def ls(owner, limit, offset):
 
 @project.command()
 @click.pass_context
-@clean_outputs
 def get(ctx):
     """Get info for current project, by project_name, or owner/project_name.
 
@@ -209,17 +209,21 @@ def get(ctx):
         config = polyaxon_client.client.sanitize_for_serialization(
             polyaxon_client.project_data
         )
-        cache.cache(config_manager=ProjectManager, config=config)
+        cache.cache(
+            config_manager=ProjectManager,
+            config=config,
+            owner=owner,
+            project=project_name,
+        )
+        get_project_details(polyaxon_client.project_data)
     except (ApiException, HTTPError) as e:
-        handle_cli_error(e, message="Could not get project `{}`.".format(project_name))
-        sys.exit(1)
-
-    get_project_details(polyaxon_client.project_data)
+        handle_cli_error(
+            e, message="Could not get project `{}`.".format(project_name), sys_exit=True
+        )
 
 
 @project.command()
 @click.pass_context
-@clean_outputs
 def delete(ctx):
     """Delete project.
 
@@ -264,7 +268,6 @@ def delete(ctx):
     "--private", type=bool, help="Set the visibility of the project to private/public."
 )
 @click.pass_context
-@clean_outputs
 def update(ctx, name, description, private):
     """Update project.
 
@@ -308,3 +311,36 @@ def update(ctx, name, description, private):
 
     Printer.print_success("Project updated.")
     get_project_details(response)
+
+
+@project.command()
+@click.option(
+    "--yes",
+    "-y",
+    is_flag=True,
+    default=False,
+    help="Automatic yes to prompts. "
+    'Assume "yes" as answer to all prompts and run non-interactively.',
+)
+@click.option(
+    "--url",
+    is_flag=True,
+    default=False,
+    help="Print the url of the dashboard for this project.",
+)
+@click.pass_context
+def dashboard(ctx, yes, url):
+    """Open this operation's dashboard details in browser."""
+    owner, project_name = get_project_or_local(ctx.obj.get("project"), is_cli=True)
+    dashboard_url = polyaxon_ui(settings.CLIENT_CONFIG.host)
+    project_url = "{}/{}/{}/".format(dashboard_url, owner, project_name)
+    if url:
+        Printer.print_header("The dashboard is available at: {}".format(project_url))
+        sys.exit(0)
+    if not yes:
+        click.confirm(
+            "Dashboard page will now open in your browser. Continue?",
+            abort=True,
+            default=True,
+        )
+    click.launch(project_url)
