@@ -20,16 +20,17 @@ import sys
 import yaml
 
 from collections import Mapping
+from requests import HTTPError
 from yaml.parser import ParserError  # noqa
 from yaml.scanner import ScannerError  # noqa
 
 from polyaxon.config_reader.utils import deep_update
 from polyaxon.env_vars.keys import POLYAXON_KEYS_PUBLIC_REGISTRY
-from polyaxon.exceptions import PolyaxonSchemaError
+from polyaxon.exceptions import PolyaxonClientException, PolyaxonSchemaError
 from polyaxon.utils.list_utils import to_list
 
 
-class ConfigSpec(object):
+class ConfigSpec:
     def __init__(self, value, config_type=None, check_if_exists=True):
         self.value = value
         self.config_type = config_type
@@ -56,17 +57,17 @@ class ConfigSpec(object):
         if isinstance(self.value, Mapping):
             return self.value
 
-        if os.path.isfile(self.value):
-            return _read_from_file(self.value, self.config_type)
-
         # try a python file
         if isinstance(self.value, str) and (
-            self.config_type == "py" or ".py" in self.value
+            self.config_type == ".py" or ".py" in self.value
         ):
             _f_path, _f_module = _get_python_file_def(self.value)
             if _f_path and _f_module:
                 return _read_from_python(_f_path, _f_module)
 
+        if os.path.isfile(self.value):
+            return _read_from_file(self.value, self.config_type)
+
         # try reading a stream of yaml or json
         if not self.config_type or self.config_type in (".json", ".yml", ".yaml"):
             try:
@@ -136,13 +137,24 @@ def _read_from_public_hub(hub: str):
     if len(hub_values) > 2:
         raise PolyaxonSchemaError("Received an invalid hub reference: `{}`".format(hub))
     if len(hub_values) == 2:
-        hub, version = hub_values
+        hub_name, version = hub_values
     else:
-        hub, version = hub_values[0], "latest"
+        hub_name, version = hub_values[0], "latest"
     version = version or "latest"
     registry = get_default_registry()
-    url = "{}/{}/{}.yaml".format(registry, hub, version)
-    return _read_from_url(url)
+    url = "{}/{}/{}.yaml".format(registry, hub_name, version)
+    try:
+        return _read_from_url(url)
+    except HTTPError as e:
+        if e.response.status_code == 404:
+            raise PolyaxonClientException(
+                "Component `{}` was not found, "
+                "please check that the name and tag are valid".format(hub)
+            )
+        raise PolyaxonClientException(
+            "Component `{}` could not be fetched, "
+            "an error was encountered".format(hub, e)
+        )
 
 
 def _read_from_stream(stream):
@@ -153,7 +165,7 @@ def _read_from_stream(stream):
 
 
 def _get_python_file_def(f_path):
-    if isinstance(f_path, str) and ".py" in f_path:
+    if not isinstance(f_path, str) or ".py" not in f_path:
         return None, None
     results = f_path.split(":")
 
@@ -224,8 +236,10 @@ def _read_from_yml(f_path, is_stream=False):
             return yaml.safe_load(f_path)
         with open(f_path) as f:
             return yaml.safe_load(f)
-    except (ScannerError, ParserError):
-        raise PolyaxonSchemaError("Received non valid yaml: `{}`".format(f_path))
+    except (ScannerError, ParserError) as e:
+        raise PolyaxonSchemaError(
+            "Received non valid yaml: `%s`.\n" "Yaml error %s" % (f_path, e)
+        ) from e
 
 
 def _read_from_json(f_path, is_stream=False):
@@ -237,4 +251,6 @@ def _read_from_json(f_path, is_stream=False):
     try:
         return json.loads(open(f_path).read())
     except ValueError as e:
-        raise PolyaxonSchemaError("Json error: %s" % e) from e
+        raise PolyaxonSchemaError(
+            "Received non valid json: `%s`.\n" "Json error %s" % (f_path, e)
+        ) from e
