@@ -15,6 +15,7 @@
 # limitations under the License.
 
 # General
+POLYAXON_KEYS_NO_CONFIG = "POLYAXON_NO_CONFIG"
 POLYAXON_KEYS_SERVICE = "POLYAXON_SERVICE"
 POLYAXON_KEYS_HEADER = "POLYAXON_HEADER"
 POLYAXON_KEYS_HEADER_SERVICE = "POLYAXON_HEADER_SERVICE"
@@ -37,10 +38,11 @@ POLYAXON_KEYS_CERT_FILE = "POLYAXON_CERT_FILE"
 POLYAXON_KEYS_KEY_FILE = "POLYAXON_KEY_FILE"
 POLYAXON_KEYS_ASSERT_HOSTNAME = "POLYAXON_ASSERT_HOSTNAME"
 POLYAXON_KEYS_CONNECTION_POOL_MAXSIZE = "POLYAXON_CONNECTION_POOL_MAXSIZE"
-POLYAXON_KEYS_UPLOAD_SIZE_WARN = "POLYAXON_UPLOAD_SIZE_WARN"
-POLYAXON_KEYS_UPLOAD_SIZE_MAX = "POLYAXON_UPLOAD_SIZE_MAX"
 POLYAXON_KEYS_ARCHIVE_ROOT = "POLYAXON_ARCHIVE_ROOT"
+POLYAXON_KEYS_STATIC_ROOT = "POLYAXON_STATIC_ROOT"
 POLYAXON_KEYS_CONTEXT_ROOT = "POLYAXON_CONTEXT_ROOT"
+POLYAXON_KEYS_DISABLE_ERRORS_REPORTING = "POLYAXON_DISABLE_ERRORS_REPORTING"
+POLYAXON_KEYS_INTERVALS_COMPATIBILITY_CHECK = "POLYAXON_INTERVALS_COMPATIBILITY_CHECK"
 
 # Secrets
 POLYAXON_KEYS_SECRET_KEY = "POLYAXON_SECRET_KEY"  # noqa
@@ -57,8 +59,6 @@ POLYAXON_KEYS_HASH_LENGTH = "POLYAXON_HASH_LENGTH"
 # Flags
 POLYAXON_KEYS_K8S_IN_CLUSTER = "POLYAXON_K8S_IN_CLUSTER"
 POLYAXON_KEYS_IS_MANAGED = "POLYAXON_IS_MANAGED"
-POLYAXON_KEYS_IS_SERVICE = "POLYAXON_IS_SERVICE"
-POLYAXON_KEYS_IS_LOCAL = "POLYAXON_IS_LOCAL"
 POLYAXON_KEYS_IS_OFFLINE = "POLYAXON_IS_OFFLINE"
 POLYAXON_KEYS_IS_OPS = "POLYAXON_IS_OPS"
 POLYAXON_KEYS_NO_OP = "POLYAXON_NO_OP"
@@ -73,10 +73,9 @@ POLYAXON_KEYS_AGENT_INIT = "POLYAXON_AGENT_INIT"
 POLYAXON_KEYS_AGENT_ARTIFACTS_STORE = "POLYAXON_AGENT_ARTIFACTS_STORE"
 POLYAXON_KEYS_AGENT_CONNECTIONS = "POLYAXON_AGENT_CONNECTIONS"
 POLYAXON_KEYS_AGENT_NOTIFICATION_CONNECTIONS = "POLYAXON_AGENT_NOTIFICATION_CONNECTIONS"
-POLYAXON_KEYS_AGENT_PATH = "POLYAXON_AGENT_PATH"
 POLYAXON_KEYS_SET_AGENT = "POLYAXON_SET_AGENT"
-POLYAXON_KEYS_K8S_APP_SECRET_NAME = "POLYAXON_K8S_APP_SECRET_NAME"
-POLYAXON_KEYS_AGENT_SECRET_NAME = "POLYAXON_AGENT_SECRET_NAME"
+POLYAXON_KEYS_K8S_APP_SECRET_NAME = "POLYAXON_K8S_APP_SECRET_NAME"  # noqa
+POLYAXON_KEYS_AGENT_SECRET_NAME = "POLYAXON_AGENT_SECRET_NAME"  # noqa
 POLYAXON_KEYS_AGENT_RUNS_SA = "POLYAXON_AGENT_RUNS_SA"
 
 # Connections
@@ -103,6 +102,7 @@ POLYAXON_KEYS_PROXY_STREAMS_PORT = "POLYAXON_PROXY_STREAMS_PORT"
 POLYAXON_KEYS_PROXY_STREAMS_HOST = "POLYAXON_PROXY_STREAMS_HOST"
 POLYAXON_KEYS_PROXY_API_PORT = "POLYAXON_PROXY_API_PORT"
 POLYAXON_KEYS_PROXY_API_HOST = "POLYAXON_PROXY_API_HOST"
+POLYAXON_KEYS_PROXY_API_USE_RESOLVER = "POLYAXON_PROXY_API_USE_RESOLVER"
 POLYAXON_KEYS_PROXY_SERVICES_PORT = "POLYAXON_PROXY_SERVICES_PORT"
 POLYAXON_KEYS_PROXY_SSL_PATH = "POLYAXON_PROXY_SSL_PATH"
 POLYAXON_KEYS_PROXY_SSL_ENABLED = "POLYAXON_PROXY_SSL_ENABLED"
@@ -110,6 +110,10 @@ POLYAXON_KEYS_PROXY_SERVICES = "POLYAXON_PROXY_SERVICES"
 POLYAXON_KEYS_PROXY_AUTH_ENABLED = "POLYAXON_PROXY_AUTH_ENABLED"
 POLYAXON_KEYS_PROXY_AUTH_EXTERNAL = "POLYAXON_PROXY_AUTH_EXTERNAL"
 POLYAXON_KEYS_PROXY_AUTH_USE_RESOLVER = "POLYAXON_PROXY_AUTH_USE_RESOLVER"
+POLYAXON_KEYS_UI_ADMIN_ENABLED = "POLYAXON_UI_ADMIN_ENABLED"
+POLYAXON_KEYS_UI_ENABLED = "POLYAXON_UI_ENABLED"
+POLYAXON_KEYS_UI_OFFLINE = "POLYAXON_UI_OFFLINE"
+POLYAXON_KEYS_STATIC_URL = "POLYAXON_STATIC_URL"
 POLYAXON_KEYS_DNS_USE_RESOLVER = "POLYAXON_DNS_USE_RESOLVER"
 POLYAXON_KEYS_DNS_CUSTOM_CLUSTER = "POLYAXON_DNS_CUSTOM_CLUSTER"
 POLYAXON_KEYS_DNS_BACKEND = "POLYAXON_DNS_BACKEND"
