@@ -151,7 +151,8 @@ class V1Component(BaseComponent, RunMixin, RefMixin, polyaxon_sdk.V1Component):
     This name can be a `slug`, a `slug:tag`, `org/slug`, or `org/slug:slug`.
 
     This name will be passed as the default value to all operations using this component,
-    unless the operations override the name or a `--name` is passed as an argument to the cli/client.
+    unless the operations override the name or a `--name`
+    is passed as an argument to the cli/client.
 
     ```yaml
     >>> component:
@@ -206,7 +207,15 @@ class V1Component(BaseComponent, RunMixin, RefMixin, polyaxon_sdk.V1Component):
 
     ```yaml
     >>> component:
-    >>>   queue: test
+    >>>   queue: agent-name/queue-name
+    ```
+
+    If the agent name is not specified, Polyaxon will resolve the name of the queue
+    based on the default agent.
+
+    ```yaml
+    >>> component:
+    >>>   queue: queue-name
     ```
 
     ### cache
@@ -301,7 +310,7 @@ class V1Component(BaseComponent, RunMixin, RefMixin, polyaxon_sdk.V1Component):
 
     Sometimes the outputs can be resolved immediately at execution time,
     for example a container image name, because such information is required for the
-    job to finish successfully, i.e. pushing the image with correct name,
+    job to finish successfully, i.e. pushing the image with the correct name,
     in that case you can disable `delayValidation` flag.
 
     ```yaml
@@ -330,8 +339,7 @@ class V1Component(BaseComponent, RunMixin, RefMixin, polyaxon_sdk.V1Component):
                                                                    MPI job.
         * [V1Spark](/docs/experimentation/distributed/spark-jobs/): for running a spark Application.
         * [V1Dask](/docs/experimentation/distributed/dask-jobs/): for running a Dask job.
-        * [V1Dag](/docs/automation/flow-engine/specification/): for running a DAG / workflow.
-
+        * [V1Dag](/docs/automation/flow-engine/specification/): for running a DAG/workflow.
     """
 
     SCHEMA = ComponentSchema
