@@ -23,6 +23,7 @@ from polyaxon.containers.containers import (
 from polyaxon.exceptions import PolyaxonCompilerError
 from polyaxon.polyflow import V1CompiledOperation, V1Init
 from polyaxon.schemas.cli.agent_config import AgentConfig
+from polyaxon.utils.list_utils import to_list
 
 
 class PolypodConfig:
@@ -34,6 +35,7 @@ class PolypodConfig:
         self.config_maps = None
         self.connection_by_names = {}
         self.artifacts_store = None
+        self.default_sa = None
         self.internal_auth = internal_auth
 
     def resolve(
@@ -41,8 +43,11 @@ class PolypodConfig:
     ):
         agent_config = agent_config or settings.AGENT_CONFIG
         if not agent_config:
-            raise PolyaxonCompilerError("Polypod is not configured.")
+            raise PolyaxonCompilerError(
+                "Polypod configuration not found or agent not configured."
+            )
 
+        self.default_sa = agent_config.runs_sa
         self._resolve_run_connections(
             compiled_operation=compiled_operation, agent_config=agent_config
         )
@@ -65,6 +70,12 @@ class PolypodConfig:
 
         if compiled_operation.is_job_run or compiled_operation.is_service_run:
             self._resolve_replica_connections(
+                init=compiled_operation.run.init,
+                connections=compiled_operation.run.connections,
+                agent_config=agent_config,
+            )
+        if compiled_operation.is_distributed_run:
+            self._resolve_distributed_connections(
                 compiled_operation=compiled_operation, agent_config=agent_config
             )
         if compiled_operation.is_dag_run:
@@ -78,15 +89,21 @@ class PolypodConfig:
                 agent_config=agent_config,
             )
 
-    def _get_init_connections(self, init: List[V1Init]):
-        init = init or []
-        return [i.connection for i in init if i.connection]
-
     def _resolve_connections(self, connections: List[str], agent_config: AgentConfig):
         if connections:
-            connection_by_names = {
-                c: agent_config.connections_by_names[c] for c in connections
-            }
+            connection_by_names = {}
+            missing_connections = set()
+            for c in connections:
+                if c not in agent_config.connections_by_names:
+                    missing_connections.add(c)
+                else:
+                    connection_by_names[c] = agent_config.connections_by_names[c]
+            if missing_connections:
+                raise PolyaxonCompilerError(
+                    "Some Connection refs were provided "
+                    "but were not found in the "
+                    "agent.connections catalog: `{}`".format(missing_connections)
+                )
             self.connection_by_names.update(connection_by_names)
 
     def _resolve_notification_connections(
@@ -100,12 +117,34 @@ class PolypodConfig:
             self.connection_by_names.update(connection_by_names)
 
     def _resolve_replica_connections(
+        self, connections: List[str], init: List[V1Init], agent_config: AgentConfig
+    ):
+        connections = to_list(connections, check_none=True)
+        self._resolve_connections(connections=connections, agent_config=agent_config)
+        init = to_list(init, check_none=True)
+        init = [i.connection for i in init if i.connection]
+        self._resolve_connections(connections=init, agent_config=agent_config)
+
+    def _resolve_distributed_connections(
         self, compiled_operation: V1CompiledOperation, agent_config: AgentConfig
     ):
-        self._resolve_connections(
-            connections=compiled_operation.run.connections, agent_config=agent_config
-        )
-        init_connections = self._get_init_connections(compiled_operation.run.init)
-        self._resolve_connections(
-            connections=init_connections, agent_config=agent_config
-        )
+        def _resolve_replica(replica):
+            if not replica:
+                return
+            self._resolve_replica_connections(
+                init=replica.init,
+                connections=replica.connections,
+                agent_config=agent_config,
+            )
+
+        if compiled_operation.is_mpi_job_run:
+            _resolve_replica(compiled_operation.run.launcher)
+            _resolve_replica(compiled_operation.run.worker)
+        if compiled_operation.is_tf_job_run:
+            _resolve_replica(compiled_operation.run.chief)
+            _resolve_replica(compiled_operation.run.worker)
+            _resolve_replica(compiled_operation.run.ps)
+            _resolve_replica(compiled_operation.run.evaluator)
+        if compiled_operation.is_pytorch_job_run:
+            _resolve_replica(compiled_operation.run.master)
+            _resolve_replica(compiled_operation.run.worker)
