@@ -25,11 +25,16 @@ from polyaxon.containers.containers import (
     V1PolyaxonInitContainer,
     V1PolyaxonSidecarContainer,
 )
+from polyaxon.containers.names import INIT_PREFIX, SIDECAR_PREFIX
 from polyaxon.env_vars.keys import POLYAXON_KEYS_NO_API
 from polyaxon.exceptions import PolypodException
 from polyaxon.k8s import k8s_schemas
 from polyaxon.k8s.custom_resources.operation import get_resource_name, get_run_instance
 from polyaxon.polyflow import V1Environment, V1Init, V1Plugins
+from polyaxon.polypod.common.containers import (
+    ensure_container_name,
+    sanitize_container_command_args,
+)
 from polyaxon.polypod.common.env_vars import get_env_var, get_service_env_vars
 from polyaxon.polypod.common.mounts import get_mounts
 from polyaxon.polypod.init.artifacts import get_artifacts_path_container
@@ -45,6 +50,7 @@ from polyaxon.polypod.specs.replica import ReplicaSpec
 from polyaxon.schemas.types import V1ConnectionType, V1K8sResourceType
 from polyaxon.services.auth import AuthenticationTypes
 from polyaxon.services.headers import PolyaxonServiceHeaders, PolyaxonServices
+from polyaxon.utils.http_utils import clean_host
 from polyaxon.utils.list_utils import to_list
 
 
@@ -72,6 +78,7 @@ class BaseConverter(ConverterAbstract):
     K8S_LABELS_NAME = None
     K8S_LABELS_COMPONENT = None
     K8S_LABELS_PART_OF = None
+    MAIN_CONTAINER_ID = None
 
     def __init__(
         self,
@@ -197,6 +204,7 @@ class BaseConverter(ConverterAbstract):
         )
 
         return get_main_container(
+            container_id=self.MAIN_CONTAINER_ID,
             main_container=main_container,
             volume_mounts=volume_mounts,
             log_level=log_level,
@@ -220,7 +228,12 @@ class BaseConverter(ConverterAbstract):
         artifacts_store: V1ConnectionType,
         sidecar_containers: List[k8s_schemas.V1Container],
     ) -> List[k8s_schemas.V1Container]:
+        sidecar_containers = [
+            ensure_container_name(container=c, prefix=SIDECAR_PREFIX)
+            for c in to_list(sidecar_containers, check_none=True)
+        ]
         polyaxon_sidecar_container = get_sidecar_container(
+            container_id=self.MAIN_CONTAINER_ID,
             polyaxon_sidecar=polyaxon_sidecar,
             env=self.get_polyaxon_sidecar_service_env_vars(),
             artifacts_store=artifacts_store,
@@ -228,12 +241,13 @@ class BaseConverter(ConverterAbstract):
             run_path=self.run_path,
         )
         containers = to_list(polyaxon_sidecar_container, check_none=True)
-        containers += to_list(sidecar_containers, check_none=True)
-        return containers
+        containers += sidecar_containers
+        return [sanitize_container_command_args(c) for c in containers]
 
     def handle_init_connections(
         self,
         polyaxon_init: V1PolyaxonInitContainer,
+        artifacts_store: V1ConnectionType,
         init_connections: List[V1Init],
         connection_by_names: Dict[str, V1ConnectionType],
         contexts: PluginsContextsSpec,
@@ -246,7 +260,7 @@ class BaseConverter(ConverterAbstract):
                 connection_spec = connection_by_names.get(init_connection.connection)
                 if init_connection.git:  # Update the default schema
                     connection_spec.schema.patch(init_connection.git)
-                if connection_spec.kind == V1ConnectionKind.GIT:
+                if V1ConnectionKind.is_git(connection_spec.kind):
                     containers.append(
                         get_git_init_container(
                             polyaxon_init=polyaxon_init,
@@ -270,6 +284,18 @@ class BaseConverter(ConverterAbstract):
                         )
                     )
             else:
+                # artifacts init without connection should default to the artifactsStore
+                if init_connection.artifacts:
+                    containers.append(
+                        get_store_container(
+                            polyaxon_init=polyaxon_init,
+                            connection=artifacts_store,
+                            artifacts=init_connection.artifacts,
+                            container=init_connection.container,
+                            env=self.get_init_service_env_vars(),
+                            mount_path=init_connection.path,
+                        )
+                    )
                 # git init without connection
                 if init_connection.git:
                     git_name = init_connection.git.get_name()
@@ -313,8 +339,11 @@ class BaseConverter(ConverterAbstract):
         init_containers: List[k8s_schemas.V1Container],
         connection_by_names: Dict[str, V1ConnectionType],
     ) -> List[k8s_schemas.V1Container]:
-        init_containers = init_containers or []
-        init_connections = init_connections or []
+        init_containers = [
+            ensure_container_name(container=c, prefix=INIT_PREFIX)
+            for c in to_list(init_containers, check_none=True)
+        ]
+        init_connections = to_list(init_connections, check_none=True)
         containers = []
 
         # Add auth context
@@ -339,11 +368,13 @@ class BaseConverter(ConverterAbstract):
 
         containers += self.handle_init_connections(
             polyaxon_init=polyaxon_init,
+            artifacts_store=artifacts_store,
             init_connections=init_connections,
             connection_by_names=connection_by_names,
             contexts=contexts,
         )
-        return containers + init_containers
+        init_containers = containers + init_containers
+        return [sanitize_container_command_args(c) for c in init_containers]
 
     def filter_containers_from_init(
         self, init: List[V1Init]
@@ -367,6 +398,7 @@ class BaseConverter(ConverterAbstract):
         connection_by_names: Dict[str, V1ConnectionType],
         secrets: Optional[Iterable[V1K8sResourceType]],
         config_maps: Optional[Iterable[V1K8sResourceType]],
+        default_sa: str = None,
         ports: List[int] = None,
         num_replicas: int = None,
     ) -> ReplicaSpec:
@@ -375,6 +407,9 @@ class BaseConverter(ConverterAbstract):
         sidecars = sidecars or []
         connections = connections or []
         environment = environment or V1Environment()
+        environment.service_account_name = (
+            environment.service_account_name or default_sa
+        )
 
         init_connections = self.filter_connections_from_init(init=init)
 
@@ -452,7 +487,7 @@ class PlatformConverterMixin(ConverterAbstract):
             include_agent_token=include_agent_token,
             polyaxon_default_secret_ref=settings.AGENT_CONFIG.app_secret_name,
             polyaxon_agent_secret_ref=settings.AGENT_CONFIG.agent_secret_name,
-            api_host=settings.CLIENT_CONFIG.host,
+            api_host=clean_host(settings.CLIENT_CONFIG.host),
             api_version=VERSION_V1,
         )
 
