@@ -22,7 +22,10 @@ from polyaxon.containers.contexts import (
     CONTEXT_MOUNT_ARTIFACTS,
     CONTEXT_MOUNT_ARTIFACTS_FORMAT,
 )
-from polyaxon.containers.names import INIT_ARTIFACTS_CONTAINER
+from polyaxon.containers.names import (
+    INIT_ARTIFACTS_CONTAINER_PREFIX,
+    generate_container_name,
+)
 from polyaxon.exceptions import PolypodException
 from polyaxon.k8s import k8s_schemas
 from polyaxon.polypod.common.mounts import get_artifacts_context_mount
@@ -31,7 +34,7 @@ from polyaxon.schemas.types import V1ArtifactsType, V1ConnectionType
 
 
 def get_artifacts_store_args(artifacts_path: str, clean: bool) -> str:
-    get_or_create = 'if [ ! -d "{dir}" ]; then mkdir -p {dir}; fi;'.format(
+    get_or_create = 'if [ ! -d "{dir}" ]; then mkdir -m 0777 -p {dir}; fi;'.format(
         dir=artifacts_path
     )
     delete_dir = (
@@ -45,10 +48,10 @@ def get_artifacts_store_args(artifacts_path: str, clean: bool) -> str:
 
 def init_artifact_context_args(run_path: str) -> List[str]:
     return [
-        'if [ ! -d "{dir}" ]; then mkdir -p {dir}; fi;'.format(
+        'if [ ! -d "{dir}" ]; then mkdir -m 0777 -p {dir}; fi;'.format(
             dir=CONTEXT_MOUNT_ARTIFACTS_FORMAT.format(run_path)
         ),
-        'if [ ! -d "{dir}" ]; then mkdir -p {dir}; fi;'.format(
+        'if [ ! -d "{dir}" ]; then mkdir -m 0777 -p {dir}; fi;'.format(
             dir=CONTEXT_MOUNT_ARTIFACTS_FORMAT.format(run_path) + "/outputs"
         ),
     ]
@@ -73,7 +76,7 @@ def get_artifacts_path_container(
             )
         )
 
-    container_name = INIT_ARTIFACTS_CONTAINER.format(DEFAULT)
+    container_name = generate_container_name(INIT_ARTIFACTS_CONTAINER_PREFIX, DEFAULT)
     container = k8s_schemas.V1Container(name=container_name)
 
     return get_base_store_container(
