@@ -18,9 +18,10 @@ import polyaxon_sdk
 
 from marshmallow import fields, validates_schema
 
-from polyaxon.schemas.base import BaseCamelSchema, BaseConfig
+from polyaxon.schemas.base import BaseCamelSchema
 from polyaxon.schemas.fields.docker_image import validate_image
 from polyaxon.schemas.fields.ref_or_obj import RefOrObject
+from polyaxon.schemas.types.base import BaseTypeConfig
 
 POLYAXON_DOCKERFILE_NAME = "Dockerfile"
 POLYAXON_DOCKER_WORKDIR = "/code"
@@ -50,7 +51,7 @@ class DockerfileTypeSchema(BaseCamelSchema):
         validate_image(data.get("image"))
 
 
-class V1DockerfileType(BaseConfig, polyaxon_sdk.V1DockerfileType):
+class V1DockerfileType(BaseTypeConfig, polyaxon_sdk.V1DockerfileType):
     """Dockerfile type.
 
     This type allows you to easily construct a dockerfile without
@@ -136,8 +137,28 @@ class V1DockerfileType(BaseConfig, polyaxon_sdk.V1DockerfileType):
       * filename: an optional name for your dockerfile, default is Dockerfile.
       * workdir: the WORKDIR for your dockerfile, default is `/code`
       * workdirPath: the local workdir to copy to the docker container.
-      * shell: shell type environment variable, default `/bin/bash`
+      * shell: shell type environment variable, default `/bin/bash`.
 
+    ### Example
+
+    ```yaml
+    image: image:tag
+    env:
+      KEY1: value1
+      KEY2: value2
+    path:
+    - module/add/to/path
+    copy:
+    - copy/local/path
+    run:
+    - pip install ...
+    - mv foo bar
+    langEnv: en_US.UTF-8
+    uid: 2222
+    gid: 1111
+    filename: Dockerfile2
+    workdir: ../my-code
+    ```
     """
 
     IDENTIFIER = "dockerfile"
