@@ -18,6 +18,20 @@ from typing import Any, Optional
 from urllib.parse import parse_qs, urlencode, urljoin, urlparse, urlunparse
 
 
+def clean_verify_ssl(host: str, verify_ssl: bool = None):
+    if verify_ssl is None and "https" in host:
+        return True
+    return verify_ssl
+
+
+def clean_host(host: str):
+    return host.rstrip("/")
+
+
+def polyaxon_ui(host: str):
+    return "{}/ui".format(clean_host(host))
+
+
 def absolute_uri(url: str, api_host: str = None, protocol: str = None) -> Optional[str]:
     if not url:
         return None
@@ -26,7 +40,7 @@ def absolute_uri(url: str, api_host: str = None, protocol: str = None) -> Option
         return url
     protocol = protocol or "http"
 
-    url = urljoin(api_host.rstrip("/") + "/", url.lstrip("/"))
+    url = urljoin(clean_host(api_host) + "/", url.lstrip("/"))
     return f"{protocol}://{url}"
 
 
